aboutsummaryrefslogtreecommitdiff
path: root/src/property/installer.lisp
diff options
context:
space:
mode:
authorSean Whitton <spwhitton@spwhitton.name>2022-04-03 09:34:37 -0700
committerSean Whitton <spwhitton@spwhitton.name>2022-04-04 14:47:02 -0700
commit006d3969bad1f84c0133a36ed9a623b59bd01c0e (patch)
treeb16c80a6b3d9930dc98f3e3d141a8dabd075b05d /src/property/installer.lisp
parent6195f10ed2c7c8999b2fd8078a12c6c84cb5a592 (diff)
downloadconsfigurator-006d3969bad1f84c0133a36ed9a623b59bd01c0e.tar.gz
rename basic propapp accessors
Signed-off-by: Sean Whitton <spwhitton@spwhitton.name>
Diffstat (limited to 'src/property/installer.lisp')
-rw-r--r--src/property/installer.lisp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/property/installer.lisp b/src/property/installer.lisp
index 60c17d7..bad2255 100644
--- a/src/property/installer.lisp
+++ b/src/property/installer.lisp
@@ -57,7 +57,7 @@ BOOTLOADER-TYPE to VOLUME."))
%install-bootloaders (running-on-target &rest propapps)
(:retprop
:type :lisp
- :hostattrs (lambda () (mapc #'propappattrs propapps))
+ :hostattrs (lambda () (mapc #'propapp-attrs propapps))
:apply
(lambda ()
(mapc #'consfigure
@@ -160,10 +160,10 @@ using a combinator like ON-CHANGE, or applied manually with DEPLOY-THESE."
;;; the definition of SERVICES:WITHOUT-STARTING-SERVICES to *AT-END-FUNCTIONS*
;;; in a closure. We'd also want %CONSFIGURE to use UNWIND-PROTECT to ensure
;;; that the AT-END functions get run even when there's a nonlocal exit from
-;;; %CONSFIGURE's call to PROPAPPAPPLY; perhaps we could pass a second
+;;; %CONSFIGURE's call to APPLY-PROPAPP; perhaps we could pass a second
;;; argument to the AT-END functions indicating whether there was a non-local
;;; transfer of control. REBOOT:REBOOTED-AT-END might only reboot when there
;;; was a normal return from PROPAPPAPPLY, whereas the cleanup forms from
;;; SERVICES:WITHOUT-STARTING-SERVICES would always be evaluated.
(defprop %root-filesystems-flipped :lisp (new-os old-os)
@@ -160,10 +160,10 @@ using a combinator like ON-CHANGE, or applied manually with DEPLOY-THESE."
;;; argument to the AT-END functions indicating whether there was a non-local
;;; transfer of control. REBOOT:REBOOTED-AT-END might only reboot when there
-;;; was a normal return from PROPAPPAPPLY, whereas the cleanup forms from
+;;; was a normal return from APPLY-PROPAPP, whereas the cleanup forms from
;;; SERVICES:WITHOUT-STARTING-SERVICES would always be evaluated.
(defprop %root-filesystems-flipped :lisp (new-os old-os)